@@ -2,7 +2,7 @@
 
 nodes and widgets for reducing data dimensionality.
 """
-from typing import Dict, Any, Tuple, Type, Optional, List, Union, cast
+from typing import Dict, Any, Tuple, Type, Optional, List, Union, cast, Callable
 from enum import Enum, unique
 
 from typing_extensions import TypedDict
@@ -56,7 +56,7 @@ class ReductionMethod(Enum):
 
 
 #: mapping from reduction method Enum to functions
-reductionFunc = {
+reductionFunc: Dict[ReductionMethod, Callable[..., Any]] = {
     ReductionMethod.elementSelection: selectAxisElement,
     ReductionMethod.average: np.mean,
 }
@@ -518,10 +518,12 @@ class DimensionReducer(Node):
 
                     # support for both pre-defined and custom functions
                     if isinstance(fun, ReductionMethod):
-                        funCall = reductionFunc[fun]
+                        funCall: Optional[Callable[..., Any]] = reductionFunc[fun]
                     else:
                         funCall = fun
 
+                    if funCall is None:
+                        raise RuntimeError("Reduction function is None")
                     newvals = funCall(data[n]['values'], *arg, **kw)
                     if newvals.shape != targetShape:
                         self.logger().error(
@@ -554,10 +556,14 @@ class DimensionReducer(Node):
           the second element is taken as the arg-list.
           The function can be of type :class:`.ReductionMethod`.
         """
-
         delete = []
         for ax, reduction in self._reductions.items():
 
+            if ax not in data.axes():
+                self.logger().warning(f"{ax} is not a known dimension. Removing.")
+                delete.append(ax)
+                continue
+
             if reduction is None:
                 if isinstance(data, MeshgridDataDict):
                     self.logger().warning(f'Reduction for axis {ax} is None. '
@@ -597,6 +603,7 @@ class DimensionReducer(Node):
                 self.logger().info(f'Reduction set for axis {ax} is only suited for '
                                    f'grid data. Removing.')
                 delete.append(ax)
+                continue
 
             # set the reduction in the correct format.
             self._reductions[ax] = (fun, arg, kw)
@@ -815,7 +822,6 @@ class XYSelector(DimensionReducer):
             self.optionChangeNotification.emit(
                 {'dimensionRoles': self.dimensionRoles}
             )
-
         return True
 
     def process(
